export default function () {
    return {
        voicemailSettings: null,
        voicemailGreetings: [],
        reminderData: null,
        speedDials: [],
        outboundSockets: [],
        callDetails: null
    }
}
